@@ -43,7 +43,7 @@ def test_circle():
 
 def test_rectangle():
     rect = Shape.rectangle([[-1, -1], [1, 1]])
-    other_rect = Shape.regular_polygon([0, 0], np.sqrt(2), 4, start_angle=45)
+    other_rect = Shape.regular_polygon([0, 0], np.sqrt(2), 4, start_angle=np.pi/4)
     assert rect == other_rect
 
 
@@ -112,6 +112,10 @@ def test_update():
     shape.update(1)
     assert np.all(np.isclose(shape.center, [1, 1]))
 
+    shape = Shape.regular_polygon([0, 0], 1, 6, angular_velocity=1, velocity=[-2, 2])
+    shape.update(0.5)
+    assert shape == Shape.regular_polygon([-1, 1], 1, 6, angular_velocity=1, velocity=[-2, 2], start_angle=0.5)
+
 
 def test_repr():
     shape = Shape.circle([0, 0], 1, velocity=[1, 1], color=(1, 2, 3), colors={'a': (20, 6, 169)})
@@ -124,11 +128,51 @@ def test_translate():
     assert shape == Shape.circle([10, 10], 1)
 
 
-def test_resize():
+def test_scale():
     shape = Shape.circle([0, 0], 1)
     shape.scale(10)
     assert shape == Shape.circle([0, 0], 10)
 
+    shape = Shape.rectangle([[-1, -1], [1, 1]])
+    shape.scale([2, 5])
+    assert shape == Shape.rectangle([[-2, -5], [2, 5]])
+
+    shape = Shape.rectangle([[-1, -1], [1, 1]])
+    shape.scale(2, center=[1, 1])
+    assert shape == Shape.rectangle([[-3, -3], [1, 1]])
+
+
+def test_rotate():
+    shape = Shape.rectangle([[-1, -1], [1, 1]])
+    shape.rotate(np.pi/2)
+    assert shape == Shape.rectangle([[-1, -1], [1, 1]])
+    shape.rotate(np.pi/4)
+    assert shape == Shape.regular_polygon([0, 0], np.sqrt(2), 4)
+
+    shape = Shape.rectangle([[-1, -1], [1, 1]])
+    shape.rotate(np.pi/2, [1, 1])
+    assert shape == Shape.rectangle([[1, -1], [3, 1]])
+
+
+def test_flip():
+    shape = Shape.rectangle([[-1, -1], [1, 1]])
+    shape.flip_x()
+    assert shape == Shape.rectangle([[-1, -1], [1, 1]])
+    shape.flip_y()
+    assert shape == Shape.rectangle([[-1, -1], [1, 1]])
+
+    shape.flip_x([1, 0])
+    assert shape == Shape.rectangle([[1, -1], [3, 1]])
+
+    shape.flip_y([0, 1])
+    assert shape == Shape.rectangle([[1, 1], [3, 3]])
+
+    shape -= [2, 2]
+    shape.flip(np.pi/4)
+    assert shape == Shape.rectangle([[-1, -1], [1, 1]])
+    shape.flip(np.pi/4, center=[-1, 1])
+    assert shape == Shape.rectangle([[-3, 1], [-1, 3]])
+
 
 def test_from_polygon():
     shape = Shape.circle([0, 0], 1)
@@ -181,6 +225,26 @@ def test_covers():
     assert a.covers(b)
 
 
+def test_union():
+    assert (Shape.rectangle([[-1, 0], [0, 1]]) | Shape.rectangle([[0, 0], [1, 1]]) ==
+            Shape.rectangle([[-1, 0], [0, 1]]) + Shape.rectangle([[0, 0], [1, 1]]) ==
+            Shape.rectangle([[-1, 0], [1, 1]]))
+
+
+def test_intersection():
+    assert Shape.rectangle([[-1, 0], [1, 2]]) & Shape.rectangle([[0, 0], [1, 1]]) == Shape.rectangle([[0, 0], [1, 1]])
+
+
+def test_difference():
+    assert Shape.rectangle([[-1, 0], [1, 3]]) - Shape.rectangle([[0, 0], [2, 3]]) == Shape.rectangle([[-1, 0], [0, 3]])
+
+
+def test_xor():
+    assert Shape.rectangle([[-1, 0], [0, 1]]) ^ Shape.rectangle([[0, 0], [1, 1]]) == Shape.rectangle([[-1, 0], [1, 1]])
+    assert ((Shape.rectangle([[-1, 0], [0.5, 1]]) ^ Shape.rectangle([[-0.5, 0], [1, 1]])) ==
+            (Shape.rectangle([[-1, 0], [1, 1]])) - Shape.rectangle([[-0.5, 0], [0.5, 1]]))
+
+
 def test_center():
     shape = Shape.rectangle([[-1, -1], [1, 1]])
     assert np.all(np.isclose(shape.center, [0, 0]))
@@ -200,6 +264,11 @@ def test_distance_to():
     assert np.isclose(shape.distance_to([1, 1]), np.sqrt(2))
 
 
+def test_eq():
+    assert Shape.regular_polygon([0, 0], 1, 4) != Shape.regular_polygon([0, 0], 1, 5)
+    assert Shape.regular_polygon([0, 0], 1, 4) == Shape.regular_polygon([0, 0], 1, 4, start_angle=np.pi)
+
+
 def test_neq():
     assert Shape.circle([0, 0], 1) != 0
 
